@@ -36,7 +36,6 @@ typedef GObjectClass NautilusSignallerClass;
 
 enum {
 	HISTORY_LIST_CHANGED,
-	EMBLEMS_CHANGED,
 	POPUP_MENU_CHANGED,
 	USER_DIRS_CHANGED,
 	MIME_DATA_CHANGED,
@@ -78,14 +77,6 @@ nautilus_signaller_class_init (NautilusSignallerClass *class)
 		              NULL, NULL,
 		              g_cclosure_marshal_VOID__VOID,
 		              G_TYPE_NONE, 0);
-	signals[EMBLEMS_CHANGED] =
-		g_signal_new ("emblems_changed",
-		              G_TYPE_FROM_CLASS (class),
-		              G_SIGNAL_RUN_LAST,
-		              0,
-		              NULL, NULL,
-		              g_cclosure_marshal_VOID__VOID,
-		              G_TYPE_NONE, 0);
 	signals[POPUP_MENU_CHANGED] =
 		g_signal_new ("popup_menu_changed",
 		              G_TYPE_FROM_CLASS (class),
